==> python-autoray_0.6.12.orig.tar.gz: autoray-0.6.12/autoray/lazy/__init__.py <==
from . import linalg

from .core import (
    ascend,
    descend,
    compute,
    get_source,
    Function,
    LazyArray,
    Variable,
    shared_intermediates,
    array,
    transpose,
    reshape,
    tensordot,
    einsum,
    trace,
    diag,
    matmul,
    kron,
    clip,
    flip,
    sort,
    argsort,
    stack,
    concatenate,
    split,
    where,
    take,
    # binary
    multiply,
    add,
    floordivide,
    truedivide,
    # unary
    sin,
    cos,
    tan,
    arcsin,
    arccos,
    arctan,
    sinh,
    cosh,
    tanh,
    arcsinh,
    arccosh,
    arctanh,
    sqrt,
    exp,
    log,
    log2,
    log10,
    conj,
    sign,
    angle,
    real,
    imag,
    # reductions
    prod,
)
from .core import abs_ as abs
from .core import sum_ as sum
from .core import min_ as min
from .core import max_ as max
from .core import complex_ as complex

__all__ = (
    "ascend",
    "descend",
    "compute",
    "get_source",
    "Function",
    "LazyArray",
    "Variable",
    "shared_intermediates",
    "linalg",
    "array",
    # basic and shape changing functions
    "transpose",
    "reshape",
    "tensordot",
    "einsum",
    "conj",
    "trace",
    "diag",
    "matmul",
    "kron",
    "clip",
    "flip",
    "sort",
    "argsort",
    "stack",
    "concatenate",
    "split",
    "where",
    "take",
    # binary functions
    "multiply",
    "add",
    "floordivide",
    "truedivide",
    # unary functions
    "sin",
    "cos",
    "tan",
    "arcsin",
    "arccos",
    "arctan",
    "sinh",
    "cosh",
    "tanh",
    "arcsinh",
    "arccosh",
    "arctanh",
    "sqrt",
    "exp",
    "log",
    "log2",
    "log10",
    "conj",
    "sign",
    "abs",
    "angle",
    "real",
    "imag",
    # reduction functions
    "sum",
    "prod",
    "min",
    "max",
    "complex",
)


try:
    from opt_einsum.backends.dispatch import _aliases

    _aliases["autoray"] = "autoray.lazy"
except ImportError:  # pragma: no cover
    pass

==> python-autoray_0.7.1.orig.tar.gz: autoray-0.7.1/autoray/lazy/__init__.py <==
from . import linalg

from .core import (
    add,
    angle,
    arccos,
    arccosh,
    arcsin,
    arcsinh,
    arctan,
    arctanh,
    argsort,
    array,
    ascend,
    clip,
    compute,
    concatenate,
    conj,
    cos,
    cosh,
    descend,
    diag,
    einsum,
    empty,
    exp,
    eye,
    flip,
    floordivide,
    Function,
    get_source,
    identity,
    imag,
    kron,
    LazyArray,
    log,
    log10,
    log2,
    matmul,
    multiply,
    ones,
    prod,
    real,
    reshape,
    shared_intermediates,
    sign,
    sin,
    sinh,
    sort,
    split,
    sqrt,
    stack,
    take,
    tan,
    tanh,
    tensordot,
    trace,
    transpose,
    truedivide,
    Variable,
    where,
    zeros,
)
from .core import abs_ as abs
from .core import sum_ as sum
from .core import min_ as min
from .core import max_ as max
from .core import complex_ as complex

__all__ = (
    "abs",
    "add",
    "angle",
    "arccos",
    "arccosh",
    "arcsin",
    "arcsinh",
    "arctan",
    "arctanh",
    "argsort",
    "array",
    "ascend",
    "clip",
    "complex",
    "compute",
    "concatenate",
    "conj",
    "conj",
    "cos",
    "cosh",
    "descend",
    "diag",
    "einsum",
    "empty",
    "exp",
    "eye",
    "flip",
    "floordivide",
    "Function",
    "get_source",
    "identity",
    "imag",
    "kron",
    "LazyArray",
    "linalg",
    "log",
    "log10",
    "log2",
    "matmul",
    "max",
    "min",
    "multiply",
    "ones",
    "prod",
    "real",
    "reshape",
    "shared_intermediates",
    "sign",
    "sin",
    "sinh",
    "sort",
    "split",
    "sqrt",
    "stack",
    "sum",
    "take",
    "tan",
    "tanh",
    "tensordot",
    "trace",
    "transpose",
    "truedivide",
    "Variable",
    "where",
    "zeros",
)


try:
    from opt_einsum.backends.dispatch import _aliases

    _aliases["autoray"] = "autoray.lazy"
except ImportError:  # pragma: no cover
    pass
